@@ -19,38 +19,35 @@
 #define IDENTITYDIALOG_H
 
 #include <kopeteinfodialog.h>
-#include <kopete_export.h>
+#include <kopeteidentity_export.h>
 
-namespace Kopete
-{
+namespace Kopete {
 class Identity;
 }
 
-class KOPETE_IDENTITY_EXPORT IdentityDialog : public Kopete::UI::InfoDialog
+class KOPETEIDENTITY_EXPORT IdentityDialog : public Kopete::UI::InfoDialog
 {
-	Q_OBJECT
+    Q_OBJECT
 public:
-	explicit IdentityDialog(Kopete::Identity *identity, QWidget *parent = 0);
-	~IdentityDialog();
+    explicit IdentityDialog(Kopete::Identity *identity, QWidget *parent = nullptr);
+    ~IdentityDialog();
 
-protected slots:
-	void load();
-	virtual void slotSave();
+protected Q_SLOTS:
+    void load();
+    void slotSave() Q_DECL_OVERRIDE;
 
-private slots:
-	void slotSelectPhoto();
-	void slotClearPhoto();
+private Q_SLOTS:
+    void slotSelectPhoto();
+    void slotClearPhoto();
 
 protected:
-	void setPhoto(QString path);
+    void setPhoto(QString path);
 
 private:
-	class Private;
-	Private * const d;
-
+    class Private;
+    Private *const d;
 };
 
-
 #endif
 
 // vim: set noet ts=4 sts=4 sw=4:
